@@ -22,6 +22,23 @@ class CustomEventMessage(object):
     def set_product_id(self, product_id):
         self.product_id = product_id
 
+    def __str__(self):
+        message_str = '{event_type:' + self.event_type
+        message_str += ',event_name:' + self.event_name
+        message_str += ',product_id:' + self.product_id
+        message_str += ',data_source_id:' + self.data_source_id
+        message_str += ',event_time:' + str(self.event_time)
+        if self.anonymous_id is not None:
+            message_str += ',anonymous_id:' + self.anonymous_id
+        if self.login_user_key is not None:
+            message_str += ',login_user_key:' + self.login_user_key
+        if self.login_user_id is not None:
+            message_str += ',login_user_id:' + self.login_user_id
+        if self.attributes is not None:
+            message_str += ',attributes:' + str(self.attributes)
+        message_str += '}'
+        return message_str
+
     class EventBuilder(object):
         def __init__(self):
             self.data_source_id = None
@@ -103,6 +120,22 @@ class UserLoginMessage(object):
     def set_product_id(self, product_id):
         self.product_id = product_id
 
+    def __str__(self):
+        message_str = '{event_type:' + self.event_type
+        message_str += ',product_id:' + self.product_id
+        message_str += ',data_source_id:' + self.data_source_id
+        message_str += ',event_time:' + str(self.event_time)
+        if self.anonymous_id is not None:
+            message_str += ',anonymous_id:' + self.anonymous_id
+        if self.login_user_key is not None:
+            message_str += ',login_user_key:' + self.login_user_key
+        if self.login_user_id is not None:
+            message_str += ',login_user_id:' + self.login_user_id
+        if self.attributes is not None:
+            message_str += ',attributes:' + str(self.attributes)
+        message_str += '}'
+        return message_str
+
     class UserBuilder(object):
         def __init__(self):
             self.data_source_id = None
@@ -172,6 +205,16 @@ class ItemMessage(object):
     def set_product_id(self, product_id):
         self.product_id = product_id
 
+    def __str__(self):
+        message_str = '{item_key:' + str(self.key)
+        message_str += ',item_id:' + str(self.id)
+        message_str += ',product_id:' + self.product_id
+        message_str += ',data_source_id:' + self.data_source_id
+        if self.attrs is not None:
+            message_str += ',attributes:' + str(self.attrs)
+        message_str += '}'
+        return message_str
+
     class ItemBuilder(object):
         def __init__(self):
             self.data_source_id = None
